@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: flag_c.c,v 1.6 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: flag_c.c,v 1.7 2001/10/16 15:24:26 diaz Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -698,7 +698,9 @@ Write_Pl_State_File(WamWord file_word)
   OperInf *oper;
   SFOp sf_op;
   int c;
-  char cv[2];
+/* 'static' is because gcc allocates a frame even with -fomit-frame-pointer.
+ * This corrupts ebp on ix86 */
+  static char cv[2];
 
 
   file = atom_tbl[Rd_Atom_Check(file_word)].name;
