@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: os_interf_c.c,v 1.4 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: os_interf_c.c,v 1.6 2001/09/17 16:01:51 diaz Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -727,13 +727,12 @@ Temporary_Name_2(WamWord template_word, WamWord path_name_word)
 {
   char *template;
   char *path_name;
-
+ 
   template = Get_Path_Name(template_word);
-
-  errno = -1;
-  path_name = (char *) mktemp(template);
+ 
+  path_name = M_Mktemp(template);
   Os_Test_Error(path_name == NULL);
-
+ 
   return path_name && Un_String_Check(path_name, path_name_word);
 }
 
@@ -751,21 +750,20 @@ Temporary_File_3(WamWord dir_word, WamWord prefix_word,
   char *dir;
   char *prefix;
   char *path_name;
-
+ 
   dir = Rd_String_Check(dir_word);
   if (*dir == '\0')
     dir = NULL;
   else
     dir = Get_Path_Name(dir_word);
-
+ 
   prefix = Rd_String_Check(prefix_word);
   if (*prefix == '\0')
     prefix = NULL;
-
-  errno = -1;
-  path_name = (char *) tempnam(dir, prefix);
+ 
+  path_name = M_Tempnam(dir, prefix);
   Os_Test_Error(path_name == NULL);
-
+ 
   return path_name && Un_String_Check(path_name, path_name_word);
 }
 
@@ -1327,7 +1325,7 @@ Send_Signal_2(WamWord pid_word, WamWord signal_word)
       }
     else
       {
-	errno = -1;
+	errno = 0;
 	ret = raise(sig);
       }
 
