@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: pretty_c.c,v 1.4 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: pretty_c.c,v 1.5 2001/09/17 16:01:51 diaz Exp $ */
 
 #define OBJ_INIT Pretty_Initializer
 
@@ -83,14 +83,12 @@ static int nb_to_try;
 
 static void Portray_Clause(StmInf *pstm, WamWord term_word);
 
-static
-  Bool Check_Structure(WamWord term_word, int func, int arity,
-		       WamWord arg_word[]);
+static Bool Check_Structure(WamWord term_word, int func, int arity,
+			    WamWord arg_word[]);
 
 static Bool Is_Cut(WamWord body_word);
 
-static
-  void Show_Body(StmInf *pstm, int level, int context, WamWord body_word);
+static void Show_Body(StmInf *pstm, int level, int context, WamWord body_word);
 
 static void Start_Line(StmInf *pstm, int level, char c_before);
 
@@ -505,7 +503,7 @@ Name_Query_Vars_2(WamWord query_list_word, WamWord rest_list_word)
 
 
 
-#define BIND_WITH_NUMBERVAR        (sys_var[0]==0)
+#define BIND_WITH_NUMBERVAR        (sys_var[0] == 0)
 
 
 /*-------------------------------------------------------------------------*
