@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: write_supp.c,v 1.5 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: write_supp.c,v 1.7 2001/09/28 18:26:47 diaz Exp $ */
 
 #include <string.h>
 #include <ctype.h>
@@ -35,6 +35,12 @@
 #include "bips_pl.h"
 
 
+				/* define to only put spaces for fx, xfx, xf */
+#if 0
+#define SPACE_ARGS_RESTRICTED
+#endif
+
+
 
 
 /*---------------------------------*
@@ -641,7 +647,11 @@ Show_Structure(int depth, int prec, int context, WamWord *stc_adr)
   if (f_n == curly_brackets_1)
     {
       Out_Char('{');
+      if (space_args)
+	Out_Char(' ');
       Show_Term(depth, MAX_PREC, GENERAL_TERM, Arg(stc_adr, 0));
+      if (space_args)
+	Out_Char(' ');
       Out_Char('}');
       return;
     }
@@ -676,8 +686,18 @@ Show_Structure(int depth, int prec, int context, WamWord *stc_adr)
 
       Show_Atom(GENERAL_TERM, functor);
 
-      last_prefix_op = (strcmp(atom_tbl[functor].name, "-") == 0)
-	? W_PREFIX_OP_MINUS : W_PREFIX_OP_ANY;
+      last_prefix_op = W_PREFIX_OP_ANY;
+
+      if (space_args
+#if SPACE_ARGS_RESTRICTED	/* space_args -> space after fx operator */
+	  && oper->prec > oper->right
+#endif
+	  )
+	Out_Char(' ');
+      else
+	if (strcmp(atom_tbl[functor].name, "-") == 0)
+	  last_prefix_op = W_PREFIX_OP_MINUS;
+
       Show_Term(depth, oper->right, INSIDE_ANY_OP, Arg(stc_adr, 0));
       last_prefix_op = W_NO_PREFIX_OP;
 
@@ -701,6 +721,14 @@ Show_Structure(int depth, int prec, int context, WamWord *stc_adr)
 	(oper->left == oper->prec) ? INSIDE_LEFT_ASSOC_OP : INSIDE_ANY_OP;
 
       Show_Term(depth, oper->left, context, Arg(stc_adr, 0));
+
+      if (space_args
+#if SPACE_ARGS_RESTRICTED	/* space_args -> space before xf operator */
+	  && oper->prec > oper->left
+#endif
+	  )
+	Out_Char(' ');
+
       Show_Atom(GENERAL_TERM, functor);
 
       if (bracket)
@@ -725,14 +753,23 @@ Show_Structure(int depth, int prec, int context, WamWord *stc_adr)
 
       Show_Term(depth, oper->left, context, Arg(stc_adr, 0));
 
-      if (functor == ATOM_CHAR(',') && !ignore_op)
-	Out_Char(',');
+      if (functor == ATOM_CHAR(','))
+	{
+	  Out_Char(',');
+	  if (space_args)
+	    Out_Char(' ');
+	}
       else
 	{
 	  surround_space = FALSE;
 
 	  if (atom_tbl[functor].prop.type == IDENTIFIER_ATOM ||
-	      atom_tbl[functor].prop.type == OTHER_ATOM)
+	      atom_tbl[functor].prop.type == OTHER_ATOM ||
+	      (space_args 
+#ifdef SPACE_ARGS_RESTRICTED	/* space_args -> space around xfx operators */
+	       && oper->left != oper->prec && oper->right != oper->prec
+#endif
+	       ))
 	    {
 	      surround_space = TRUE;
 	      Out_Char(' ');
