@@ -22,15 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: fd_hook_range.h,v 1.3 2001/01/23 11:38:20 diaz Exp $ */
-
-#ifdef FD_RANGE_FILE
-
-#    include "engine_pl.h"
-#    include "fd_inst.h"
-
-#endif
-
+/* $Id: fd_hook_range.h,v 1.4 2001/02/08 10:24:50 diaz Exp $ */
 
 /*---------------------------------*
  * Constants                       *
