@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: fd_range.c,v 1.5 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: fd_range.c,v 1.6 2001/02/08 10:24:50 diaz Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -31,7 +31,8 @@
 
 #define FD_RANGE_FILE
 
-#include "fd_range.h"
+#include "engine_pl.h"
+#include "engine_fd.h"
 
 
 
