@@ -22,13 +22,16 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: fd_to_c.h,v 1.3 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: fd_to_c.h,v 1.4 2001/02/08 10:24:50 diaz Exp $ */
 
 #include <stdio.h>
 
+#if 0
 #include "engine_pl.h"
 #include "engine_fd.h"
-
+#else
+#include "gprolog.h"
+#endif
 
 
 
