@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: engine.c,v 1.4 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: engine.c,v 1.5 2001/04/27 11:28:17 spa Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -99,9 +99,9 @@ Start_Prolog(int argc, char *argv[])
   int i, x;
   char *p;
 
-#if 0				/* causes pb when printing float numbers ... */
-  setlocale(LC_ALL, "");
-#endif
+  setlocale (LC_ALL, "");
+  setlocale (LC_NUMERIC, "C");	/* make sure floats come out right... */
+
   Init_Machine();
 
   os_argc = argc;
