@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: machine1.h,v 1.3 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: machine1.h,v 1.4 2001/09/17 16:01:51 diaz Exp $ */
 
 #include <stdio.h>
 
@@ -83,4 +83,10 @@ int M_Get_Status(int pid);
 
 
 
+char *M_Mktemp(char *template);
+
+char *M_Tempnam(char *dir, char *pfx);
+
+
+
 #define   DBGPRINTF             printf
