@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: wam_inst.h,v 1.5 2001/01/23 11:38:20 diaz Exp $ */
+/* $Id: wam_inst.h,v 1.6 2001/01/25 17:16:46 diaz Exp $ */
 
 /*---------------------------------*
  * Constants                       *
@@ -339,9 +339,9 @@ void Untrail(WamWord *low_adr) FC;
 
 Bool Unify(WamWord start_u_word, WamWord start_v_word) FC;
 
-Bool Unify_Occurs_Check(WamWord start_u_word, WamWord start_v_word) FC;
-
-
+Bool Unify_Occurs_Check(WamWord start_u_word, WamWord start_v_word);
+				/* do not use FC since it is called directly */
+				/* from Prolog (BipsPl/unify.pl) */
 
 
 /*---------------------------------*
