@@ -1,3 +1,5 @@
+/* $Id: whole.pl,v 1.3 2001/09/17 16:01:51 diaz Exp $ */
+
 :-	include('read_file.pl').
 :-	include('bip_list.pl').
 :-	include('syn_sugar.pl').
@@ -9,9 +11,3 @@
 :-	include('indexing.pl').
 :-	include('wam_emit.pl').
 :-	include('pl2wam.pl').
-
-/*
-
-pl2wam([pl2wam]), pl2wam([read_file]), pl2wam([bip_list]), pl2wam([syn_sugar]), pl2wam([internal]), pl2wam([code_gen]), pl2wam([reg_alloc]), pl2wam([inst_codif]), pl2wam([first_arg]), pl2wam([indexing]), pl2wam([wam_emit]).
-
-*/
