@@ -22,7 +22,7 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: top_level.c,v 1.3 2001/01/23 11:38:21 diaz Exp $ */
+/* $Id: top_level.c,v 1.4 2001/09/17 16:01:51 diaz Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -113,15 +113,14 @@ Top_Level_Initializer(void)
  *-------------------------------------------------------------------------*/
 static void
 Display_Help(void)
-#define L(msg)  fprintf(stderr,"%s\n",msg);
+#define L(msg)  fprintf(stderr,"%s\n",msg)
 {
   fprintf(stderr, "Usage: %s [OPTION]... \n", TOP_LEVEL);
   L(" ");
   L("  -h, --help                  print this help and exit");
   L("  --version                   print version number and exit");
-  L
-    ("  --                          do not check following arguments (passed to Prolog")
-    L("");
+  L("  --                          do not check following arguments (passed to Prolog");
+  L("");
   L("Report bugs to bug-prolog@gnu.org.");
 }
 
