@@ -22,12 +22,13 @@
  * 59 Temple Place - Suite 330, Boston, MA 02111, USA.                     *
  *-------------------------------------------------------------------------*/
 
-/* $Id: wam2ma.c,v 1.5 2001/01/23 11:38:21 diaz Exp $ */
+/* $Id: wam2ma.c,v 1.7 2001/04/27 11:23:42 spa Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
+#include <locale.h>
 
 #include "wam_parser.h"
 #include "../EnginePl/gp_config.h"
@@ -346,6 +347,9 @@ main(int argc, char *argv[])
 {
   Parse_Arguments(argc, argv);
 
+  setlocale (LC_ALL, "");
+  setlocale (LC_NUMERIC, "C");	/* make sure floats come out right... */
+
   if (file_name_out == NULL)
     file_out = stdout;
   else if ((file_out = fopen(file_name_out, "wt")) == NULL)
